==> pyrcb2-0.6.0.tar.gz: pyrcb2-0.6.0/setup.py <==
#!/usr/bin/env python3
# Copyright (C) 2016-2017 taylor.fish <contact@taylor.fish>
#
# This file is part of pyrcb2.
#
# pyrcb2 is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# As an additional permission under GNU GPL version 3 section 7, you may
# distribute non-source forms of comments (lines beginning with "#") and
# strings (text enclosed in quotation marks) in pyrcb2 source code without
# the copy of the GNU GPL normally required by section 4, provided you
# include a URL through which recipients can obtain a copy of the
# Corresponding Source and the GPL at no charge.
#
# pyrcb2 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with pyrcb2.  If not, see <http://www.gnu.org/licenses/>.

from setuptools import setup
import os

SCRIPT_DIR = os.path.dirname(os.path.realpath(__file__))
with open(os.path.join(SCRIPT_DIR, "misc/pypi-description.rst")) as f:
    LONG_DESCRIPTION = f.read()

setup(
    name="pyrcb2",
    version="0.6.0",
    description="An asyncio-based IRC bot library.",
    long_description=LONG_DESCRIPTION,
    url="https://github.com/taylordotfish/pyrcb2",
    author="taylor.fish",
    author_email="contact@taylor.fish",
    license="GNU Lesser General Public License v3 or later (LGPLv3+)",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Topic :: Internet",
        "License :: OSI Approved :: "
        "GNU Lesser General Public License v3 or later (LGPLv3+)",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
    keywords="irc bot asyncio",
    packages=["pyrcb2"],
)

==> pyrcb2_0.6.2.orig.tar.gz: pyrcb2-0.6.2/setup.py <==
#!/usr/bin/env python3
# Copyright (C) 2016-2017 taylor.fish <contact@taylor.fish>
#
# This file is part of pyrcb2.
#
# pyrcb2 is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# As an additional permission under GNU GPL version 3 section 7, you may
# distribute non-source forms of comments (lines beginning with "#") and
# strings (text enclosed in quotation marks) in pyrcb2 source code without
# the copy of the GNU GPL normally required by section 4, provided you
# include a URL through which recipients can obtain a copy of the
# Corresponding Source and the GPL at no charge.
#
# pyrcb2 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with pyrcb2.  If not, see <http://www.gnu.org/licenses/>.

from setuptools import setup
import os

SCRIPT_DIR = os.path.dirname(os.path.realpath(__file__))
DESCRIPTION_URL = os.path.join(SCRIPT_DIR, "misc/pypi-description.rst")
with open(DESCRIPTION_URL, encoding="utf8") as f:
    LONG_DESCRIPTION = f.read()

setup(
    name="pyrcb2",
    version="0.6.2",
    description="An asyncio-based IRC bot library.",
    long_description=LONG_DESCRIPTION,
    url="https://github.com/taylordotfish/pyrcb2",
    author="taylor.fish",
    author_email="contact@taylor.fish",
    license="GNU Lesser General Public License v3 or later (LGPLv3+)",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Topic :: Internet",
        "License :: OSI Approved :: "
        "GNU Lesser General Public License v3 or later (LGPLv3+)",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
    keywords="irc bot asyncio",
    packages=["pyrcb2"],
    python_requires=">=3.7",
)
